@@ -54,13 +54,13 @@ setGeneric("lme",
                    model = TRUE, x = FALSE, y = FALSE,...)
            standardGeneric("lme"))
 
-#setGeneric("lme1",
-#          function(formula, data, random,
-#                   method = c("REML", "ML"),
-#                   control = list(),
-#                   subset, weights, na.action, offset,
-#                   model = TRUE, x = FALSE, y = FALSE,...)
-#           standardGeneric("lme1"))
+setGeneric("lme1",
+          function(formula, data, random,
+                   method = c("REML", "ML"),
+                   control = list(),
+                   subset, weights, na.action, offset,
+                   model = TRUE, x = FALSE, y = FALSE,...)
+           standardGeneric("lme1"))
 
 if (!isGeneric("LMEoptimize<-")) {
     setGeneric("LMEoptimize<-", function(x, ..., value)
