@@ -6,7 +6,8 @@ summary(fm5)
 VarCorr(fm5)
 fixef(fm5)
 ranef(fm5)
-#fm1 <- lme1(langPOST ~ IQ.ver.cen + avg.IQ.ver.cen,
-#                        data = bdf, random = ~ IQ.ver.cen | schoolNR)
+fm1 <- lme1(langPOST ~ IQ.ver.cen + avg.IQ.ver.cen,
+                        data = bdf, random = ~ IQ.ver.cen | schoolNR)
+summary(fm1)
 q("no")
 
